@@ -17,6 +17,7 @@ from adafruit_epd.ssd1608 import Adafruit_SSD1608  # pylint: disable=unused-impo
 from adafruit_epd.ssd1675 import Adafruit_SSD1675  # pylint: disable=unused-import
 from adafruit_epd.ssd1680 import Adafruit_SSD1680  # pylint: disable=unused-import
 from adafruit_epd.ssd1681 import Adafruit_SSD1681  # pylint: disable=unused-import
+from adafruit_epd.uc8151d import Adafruit_UC8151D  # pylint: disable=unused-import
 
 # First define some color constants
 WHITE = (0xFF, 0xFF, 0xFF)
@@ -45,6 +46,7 @@ busy = digitalio.DigitalInOut(board.D17)
 # display = Adafruit_SSD1681(200, 200,        # 1.54" HD Tri-color display
 # display = Adafruit_IL91874(176, 264,        # 2.7" Tri-color display
 # display = Adafruit_IL0373(152, 152,         # 1.54" Tri-color display
+# display = Adafruit_UC8151D(128, 296,        # 2.9" mono flexible display
 # display = Adafruit_IL0373(128, 296,         # 2.9" Tri-color display
 # display = Adafruit_IL0398(400, 300,         # 4.2" Tri-color display
 display = Adafruit_IL0373(
@@ -58,10 +60,14 @@ display = Adafruit_IL0373(
     busy_pin=busy,
 )
 
-# IF YOU HAVE A FLEXIBLE DISPLAY (2.13" or 2.9") uncomment these lines!
+# IF YOU HAVE A 2.13" FLEXIBLE DISPLAY uncomment these lines!
 # display.set_black_buffer(1, False)
 # display.set_color_buffer(1, False)
 
+# IF YOU HAVE A 2.9" FLEXIBLE DISPLAY uncomment these lines!
+# display.set_black_buffer(1, True)
+# display.set_color_buffer(1, True)
+
 display.rotation = 1
 
 image = Image.new("RGB", (display.width, display.height))
